pub struct HelpRegistry { /* private fields */ }Implementations
Sourceimpl HelpRegistry
impl HelpRegistry
Sourcepub fn from_entries(slices: &[&'static [HelpEntry]]) -> Self
pub fn from_entries(slices: &[&'static [HelpEntry]]) -> Self
Build a registry from multiple static entry slices (one per module).
Sourcepub fn find(&self, tag: &str) -> Option<&'static HelpEntry>
pub fn find(&self, tag: &str) -> Option<&'static HelpEntry>
Find an entry by tag (case-insensitive).
Sourcepub fn by_category(&self, category: HelpCategory) -> Vec<&'static HelpEntry>
pub fn by_category(&self, category: HelpCategory) -> Vec<&'static HelpEntry>
Return all entries in a given category, in registration order.
Sourcepub fn categories(&self) -> Vec<HelpCategory>
pub fn categories(&self) -> Vec<HelpCategory>
Return all categories that have at least one entry, in display order.
Sourcepub fn all_entries(&self) -> &[&'static HelpEntry]
pub fn all_entries(&self) -> &[&'static HelpEntry]
Return all entries in display order (grouped by category).